[Telepathy-commits] [telepathy-gabble/master] Check RequestStreams returns NotAvailable on Disconnection

Will Thompson will.thompson at collabora.co.uk
Wed Feb 4 06:11:38 PST 2009


---
 .../jingle/test-wait-for-caps-incomplete.py        |    7 ++++---
 1 files changed, 4 insertions(+), 3 deletions(-)

diff --git a/tests/twisted/jingle/test-wait-for-caps-incomplete.py b/tests/twisted/jingle/test-wait-for-caps-incomplete.py
index c57fc93..ba0a6c9 100644
--- a/tests/twisted/jingle/test-wait-for-caps-incomplete.py
+++ b/tests/twisted/jingle/test-wait-for-caps-incomplete.py
@@ -14,6 +14,7 @@ import gabbletest
 import dbus
 import time
 
+import constants
 
 def test(q, bus, conn, stream):
     jt = jingletest.JingleTest(stream, 'test at localhost', 'foo at bar.com/Foo')
@@ -57,9 +58,9 @@ def test(q, bus, conn, stream):
 
     conn.Disconnect()
 
-    # RequestStreams should now return error
-    q.expect('dbus-error', method='RequestStreams')
-
+    # RequestStreams should now return NotAvailable
+    event = q.expect('dbus-error', method='RequestStreams')
+    assert event.error.get_dbus_name() == constants.NOT_AVAILABLE, event.error
 
     q.expect('dbus-signal', signal='StatusChanged', args=[2, 1])
 
-- 
1.5.6.5




More information about the telepathy-commits mailing list